@@ -47,7 +47,7 @@ public:
 
     virtual bool isValid() const;
 
-private slots:
+private Q_SLOTS:
     void generateRandomClonedMac();
     void ssidChanged();
     void modeChanged(int mode);
